require "jekyll/giphy/embed/version"

require 'net/http'
require 'json'

module Jekyll

  # convert Giphy url to embedding html
  class GiphyEmbedding
    def get_html(id)
        url          = "https://giphy.com/services/oembed/?url=https://giphy.com/gifs/#{id}"
        uri          = URI(url)
        response     = Net::HTTP.get(uri)
        theHash      = JSON.parse(response)
        return "<img src='#{theHash['url']}' alt='#{theHash['title']}' width='#{theHash['width']}' height='#{theHash['height']}'>"
    end

    def convert(line)
      r = /^https?:\/\/giphy\.com\/gifs\/([A-Za-z0-9\-\_]+)\/?$/
      r =~ line ? get_html($~[1]) : line
    end

    def embed(content)
      content.lines.collect {|line| convert(line) }.join
    end
  end

  # parser's convert method
  module Converters
    class Markdown < Converter
      alias_method :parser_converter, :convert

      def convert(content)
        parser_converter(Jekyll::GiphyEmbedding.new.embed(content))
      end
    end
  end

  # html con
  class EmbeddingGiphyIntoHTML < Converter
    safe true
    priority :low

    def matches(ext)
      ext =~ /^\.html$/i
    end

    def output_ext(ext)
      ".html"
    end

    def convert(content)
      Jekyll::GiphyEmbedding.new.embed(content)
    end
  end

end
